#############################################################
#
#   Program: model_turnaroundtime.R
#   Project: 
# 
#   PI: 
#   Statistician: Bryan Shephard, PhD
#   Biostatistician/Programmer: Meridith Blevins, MS
#   Purpose: A linear regression may identify whether
#            pathology characteristics are increased 
#            turnaround time
#   Created: 29 July 2011
#   Revisions: 
#     
#
#############################################################

set.seed(1)
library(rms)

lrm1.d1 <- analysis
# sex_newborn.factor
# mom_age
# any_exposure
# prior_preg
# vitdsupp
# hrs_outside_newborn
# gestational_age_newborn
# birth_date_newborn
lrm1.d1$birth_date_newborn_num <- as.numeric(lrm1.d1$birth_date_newborn)  - 13000
lrm1.d1$any_exposure <- as.character(lrm1.d1$any_exposure)
lrm1.d1$any_exposure[is.na(lrm1.d1$any_exposure)] <- "No"
lrm1.d1$vitdsupp <- ifelse(!is.na(lrm1.d1$vitdsupp) & lrm1.d1$vitdsupp=="True","Yes","No")
lrm1.d1$primary_exposure <- as.character(lrm1.d1$primary_exposure)
lrm1.d1$secondary_exposure <- as.character(lrm1.d1$secondary_exposure)
lrm1.d1$primary_exposure[is.na(lrm1.d1$primary_exposure)] <- "No"
lrm1.d1$secondary_exposure[is.na(lrm1.d1$secondary_exposure)] <- "No"


lrm1.dd1 <- datadist(with(lrm1.d1,data.frame(sex_newborn.factor,mom_age,gestational_age_newborn,birth_date_newborn_num,nicu,delivery_newborn.factor,birth_wt_newborn,mom_edu.factor,mother_dress_newborn.factor,prenatalcare___1.factor,prenatalcare___2.factor,prenatalcare___3.factor,primary_exposure,secondary_exposure,vitdsupp,hrs_outside_newborn)))
lrm1.mi <- aregImpute(~sex_newborn.factor + mom_age + gestational_age_newborn + birth_date_newborn_num + birth_wt_newborn + delivery_newborn.factor + mom_edu.factor + mother_dress_newborn.factor+prenatalcare___1.factor+prenatalcare___2.factor+prenatalcare___3.factor+primary_exposure+secondary_exposure+vitdsupp+hrs_outside_newborn,n.impute=25,nk=4,data=lrm1.d1) 
options(datadist='lrm1.dd1')

########## MODEL 1: LOGISITIC REGRESSIOn
lrm1.nl <- fit.mult.impute(nicu ~ sex_newborn.factor + rcs(gestational_age_newborn,4) + rcs(birth_wt_newborn,4) + delivery_newborn.factor + rcs(mom_age,4) + mom_edu.factor + prenatalcare___1.factor + prenatalcare___2.factor + prenatalcare___3.factor + mother_dress_newborn.factor + rcs(hrs_outside_newborn,4) + primary_exposure + secondary_exposure + vitdsupp + rcs(birth_date_newborn_num,5), lrm, lrm1.mi, lrm1.d1)
lrm1.int <- fit.mult.impute(nicu ~ sex_newborn.factor + rcs(gestational_age_newborn,3) + rcs(birth_wt_newborn,3) + delivery_newborn.factor*rcs(birth_date_newborn_num,5) + mom_age + mom_edu.factor + prenatalcare___1.factor + prenatalcare___2.factor + prenatalcare___3.factor + mother_dress_newborn.factor + hrs_outside_newborn + primary_exposure + secondary_exposure + vitdsupp, lrm, lrm1.mi, lrm1.d1)
lrm1 <- fit.mult.impute(nicu ~ sex_newborn.factor + rcs(gestational_age_newborn,3) + rcs(birth_wt_newborn,3) + delivery_newborn.factor + mom_age + mom_edu.factor + prenatalcare___1.factor + prenatalcare___2.factor + prenatalcare___3.factor + mother_dress_newborn.factor + hrs_outside_newborn + primary_exposure + secondary_exposure + vitdsupp + rcs(birth_date_newborn_num,5), lrm, lrm1.mi, lrm1.d1)



lrm1_nat <- fit.mult.impute(nicu ~ sex_newborn.factor + rcs(gestational_age_newborn,3) + rcs(birth_wt_newborn,3) + delivery_newborn.factor + mom_age + mom_edu.factor + prenatalcare___1.factor + prenatalcare___2.factor + prenatalcare___3.factor + mother_dress_newborn.factor + hrs_outside_newborn + primary_exposure + secondary_exposure + vitdsupp + rcs(birth_date_newborn_num,5) + mom_nationality_newborn.factor, lrm, lrm1.mi, lrm1.d1)
lrm1_nat <- fit.mult.impute(nicu ~ sex_newborn.factor + rcs(gestational_age_newborn,3) + rcs(birth_wt_newborn,3) + delivery_newborn.factor + mom_age + mom_edu.factor + prenatalcare___1.factor + prenatalcare___2.factor + prenatalcare___3.factor + mother_dress_newborn.factor + hrs_outside_newborn + primary_exposure + secondary_exposure + vitdsupp + rcs(birth_date_newborn_num,5) + mom_nationality_newborn.factor, lrm, lrm1.mi, lrm1.d1)

getlrm1 <- as.data.frame(anova(lrm1))$P
row.names(summary(lrm1))[seq(1,dim(summary(lrm1))[1],by=2)]
cdates <- as.numeric(as.Date(c("02/28/2010","03/31/2010","04/30/2010","05/31/2010","06/30/2010","07/31/2010","08/31/2010","09/30/2010","10/31/2010","11/30/2010","12/31/2010","01/31/2011","02/28/2011","03/31/2011","04/30/2011","05/31/2011","06/30/2011"), "%m/%d/%Y"))  - 13000
cdates2 <- c("02/28/2010","03/31/2010","04/30/2010","05/31/2010","06/30/2010","07/31/2010","08/31/2010","09/30/2010","10/31/2010","11/30/2010","12/31/2010","01/31/2011","02/28/2011","03/31/2011","04/30/2011","05/31/2011","06/30/2011")
cdates1 <- c("Feb 10","","","May 10","","","Aug 10","","","Nov 10","","","Feb 11","","","May 11","")
lrmsum1 <- summary(lrm1,gestational_age_newborn=c(40,34),sex_newborn="Female")[c(12,2),c(4,6,7)]
lrmsum2 <- summary(lrm1,gestational_age_newborn=c(40,36),sex_newborn="Female")[c(2),c(4,6,7)]
lrmsum3 <- summary(lrm1,gestational_age_newborn=c(40,38),sex_newborn="Female")[c(2),c(4,6,7)]
lrmsum4 <- summary(lrm1,gestational_age_newborn=c(40,42),birth_wt_newborn=c(3,2))[c(2,4),c(4,6,7)]
lrmsum5 <- summary(lrm1,birth_wt_newborn=c(3,2.5))[c(4),c(4,6,7)]
lrmsum6 <- summary(lrm1,birth_wt_newborn=c(3,3.5))[c(4,14),c(4,6,7)]
lrmsum7 <- summary(lrm1,mom_age=c(20,25),hrs_outside_newborn=c(1,2))[c(6,20,16,18,22,24,26,28,30,8,32,34,36),c(4,6,7)]
lrmsum8 <- summary(lrm1,birth_date_newborn_num=c(cdates[7],cdates[4]))[c(10),c(4,6,7)]
lrmsum9 <- summary(lrm1,birth_date_newborn_num=c(cdates[7],cdates[10]))[c(10),c(4,6,7)]
lrmsum10 <- summary(lrm1,birth_date_newborn_num=c(cdates[7],cdates[13]))[c(10),c(4,6,7)]
lrmsum11 <- summary(lrm1,birth_date_newborn_num=c(cdates[7],cdates[16]))[c(10),c(4,6,7)]
# lrmsum8 <- summary(lrm1,birth_date_newborn_num=c(cdates[7],cdates[]))[c(10),c(4,6,7)]


lrmsum <- rbind(lrmsum1,lrmsum2,lrmsum3,lrmsum4,lrmsum5 ,lrmsum6 ,lrmsum7 ,lrmsum8 ,lrmsum9 ,lrmsum10,lrmsum11)
lrm1.labels <- c("Male","Gestational age (weeks)","\\\\hspace{0.25in} 34","\\\\hspace{0.25in} 36","\\\\hspace{0.25in} 38","\\\\hspace{0.25in} 40 (ref)","\\\\hspace{0.25in} 42",
                 "Birth weight (kg)","\\\\hspace{0.25in} 2","\\\\hspace{0.25in} 2.5","\\\\hspace{0.25in} 3 (ref)","\\\\hspace{0.25in} 3.5","Delivery","\\\\hspace{0.25in} Vaginal (ref)","\\\\hspace{0.25in} C-section",
		 "Maternal age (per 5 years)","Mother's education","\\\\hspace{0.25in} No education","\\\\hspace{0.25in} Primary education","\\\\hspace{0.25in} Secondary education (ref)","\\\\hspace{0.25in} College/university",
                 "Any MOH prenatal care","Any UNRWA prenatal care","Any private sector prenatal care",
		 "Mother's clothing practice","\\\\hspace{0.25in} Head scarf only (ref)","\\\\hspace{0.25in} European dress","\\\\hspace{0.25in} Fully covered","Time spent outside (per hour)","Primary smoking exposure","Secondary smoking exposure","Any vitamin D supplementation",
                 "Month of birth","\\\\hspace{0.25in} May 2010","\\\\hspace{0.25in} August 2010 (ref)","\\\\hspace{0.25in} November 2010","\\\\hspace{0.25in} February 2011","\\\\hspace{0.25in} May 2011"
		  )
myformat <- function(x){format(round(x,1),nsmall=1)}
lrmsumlines1 <- paste(paste(sapply(lrmsum[,1],myformat2)," (",sapply(lrmsum[,2],myformat2),", ",sapply(lrmsum[,3],myformat2),")",sep=""),sep=" & ")
lrmsumlines2 <- c(lrmsumlines1[1],"",lrmsumlines1[2:4],"1",lrmsumlines1[5],"",lrmsumlines1[6:7],"1",lrmsumlines1[8],"","1",lrmsumlines1[9:10],"",lrmsumlines1[11:12],"1",lrmsumlines1[13:16],"","1",lrmsumlines1[17:22],"",lrmsumlines1[23],"1",lrmsumlines1[24:26])
lrm1pval <- c(sapply(getlrm1[c(1,2)],myformat4),rep("",5),sapply(getlrm1[c(4)],myformat4),rep("",4),sapply(getlrm1[c(6)],myformat4),rep("",2),sapply(getlrm1[c(7,8)],myformat4),rep("",4),sapply(getlrm1[c(9:12)],myformat4),rep("",3),sapply(getlrm1[c(13:17)],myformat4),rep("",5))
lrm1table <- paste(lrm1.labels,lrmsumlines2,lrm1pval,sep=" & ")
lrm1tabletex <- paste(lrm1table,collapse=" \\\\\\\\ ")









